%define pkg_version %(echo %version | tr -d .)

Name:          tbb
Version:       2022.1.0
Release:       1mamba
Summary:       The Threading Building Blocks library abstracts low-level threading details
Group:         Development/Tools
Vendor:        openmamba
Distribution:  openmamba
Packager:      Silvan Calarco <silvan.calarco@mambasoft.it>
URL:           https://github.com/uxlfoundation/oneTBB
Source0:       https://github.com/intel/tbb.git/v%{version}/tbb-%{version}.tar.bz2
#Source0:       https://www.threadingbuildingblocks.org/sites/default/files/software_releases/source/tbb%{pkg_version}oss_src.tgz
Source1:       http://www.threadingbuildingblocks.org/uploads/81/91/Latest%20Open%20Source%20Documentation/Getting_Started.pdf
Source2:       http://www.threadingbuildingblocks.org/uploads/81/91/Latest%20Open%20Source%20Documentation/Reference.pdf
Source3:       http://www.threadingbuildingblocks.org/uploads/81/91/Latest%20Open%20Source%20Documentation/Tutorial.pdf
Patch0:        tbb-2.2-20090809-cxxflags.patch
Patch1:        tbb-2.2-mfence.patch
License:       GPL with exceptions
## AUTOBUILDREQ-BEGIN
BuildRequires: glibc-devel
BuildRequires: libgcc
BuildRequires: libhwloc-devel
BuildRequires: libstdc++6-devel
## AUTOBUILDREQ-END
BuildRequires: net-tools
BuildRequires: util-linux-ng

%description
Threading Building Blocks (TBB) is a C++ runtime library that abstracts the low-level threading details necessary for optimal multi-core performance.  It uses common C++ templates and coding style to eliminate tedious threading implementation work.
TBB requires fewer lines of code to achieve parallelism than other threading models.  The applications you write are portable across platforms.  Since the library is also inherently scalable, no code maintenance is required as more processor cores become available.

%package -n lib%{name}
Group:         System/Libraries
Summary:       The Threading Building Blocks C++ headers and shared development libraries
Requires:      %{name} = %{?epoch:%epoch:}%{version}-%{release}
Provides:      %{name}
Obsoletes:     %{name} < 2021.5.0

%description -n lib%{name}
Threading Building Blocks (TBB) is a C++ runtime library that abstracts the low-level threading details necessary for optimal multi-core performance.  It uses common C++ templates and coding style to eliminate tedious threading implementation work.
TBB requires fewer lines of code to achieve parallelism than other threading models.  The applications you write are portable across platforms.  Since the library is also inherently scalable, no code maintenance is required as more processor cores become available.
This package contains header files and shared object symlinks for the Threading Building Blocks (TBB) C++ libraries.

%package -n lib%{name}-devel
Group:         Development/Libraries
Summary:       The Threading Building Blocks C++ headers and shared development libraries
Requires:      lib%{name} = %{?epoch:%epoch:}%{version}-%{release}
Provides:      %{name}-devel
Obsoletes:     %{name}-devel < 2021.5.0

%description -n lib%{name}-devel
The Threading Building Blocks library abstracts low-level threading details.
This package contains header files and shared object symlinks for the Threading Building Blocks (TBB) C++ libraries.

%package doc
Group:         Documentation
Summary:       The Threading Building Blocks documentation

%description doc
The Threading Building Blocks library abstracts low-level threading details.
This package contains the Threading Building Blocks (TBB) documentation.


%prep
%setup -q
#-D -T

%build
#:<< _EOF
%cmake -d build \
   -DCMAKE_STRIP=/bin/true \
   -DCMAKE_CXX_FLAGS="%{optflags} -Wno-uninitialized -Wno-array-bounds -Wno-use-after-free -Wno-address -Wno-stringop-overflow"

#% make CXXFLAGS="$RPM_OPT_FLAGS" tbb_build_prefix=obj
#cp -p "%{SOURCE1}" "%{SOURCE2}" "%{SOURCE3}" .

%make

%install
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"

%makeinstall -C build

%clean
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"


%files -n lib%{name}
%defattr(-,root,root)
%{_libdir}/libtbb.so.*
%{_libdir}/libtbbmalloc.so.*
%{_libdir}/libtbbbind_2_5.so.*
%{_libdir}/libtbbmalloc_proxy.so.*
%doc LICENSE.txt

%files -n lib%{name}-devel
%defattr(-,root,root)
%dir %{_includedir}/tbb
%{_includedir}/tbb/*.h
%{_includedir}/oneapi/tbb.h
%dir %{_includedir}/oneapi/tbb
%{_includedir}/oneapi/tbb/*
%{_libdir}/libtbb.so
%{_libdir}/libtbbmalloc.so
%{_libdir}/libtbbbind_2_5.so
%{_libdir}/libtbbmalloc_proxy.so
%{_libdir}/pkgconfig/tbb*.pc
%dir %{_libdir}/cmake/TBB
%{_libdir}/cmake/TBB/TBB*.cmake
%{_datadir}/doc/TBB/README.md
%doc README.md

#%files doc
#%defattr(-,root,root)
#%doc Getting_Started.pdf Reference.pdf Tutorial.pdf

%changelog
* Thu Mar 27 2025 Automatic Build System <autodist@openmamba.org> 2022.1.0-1mamba
- automatic version update by autodist

* Sat Nov 02 2024 Automatic Build System <autodist@openmamba.org> 2022.0.0-1mamba
- automatic version update by autodist

* Wed Jun 26 2024 Automatic Build System <autodist@openmamba.org> 2021.13.0-1mamba
- automatic version update by autodist

* Fri Apr 12 2024 Automatic Build System <autodist@openmamba.org> 2021.12.0-1mamba
- automatic version update by autodist

* Mon Nov 20 2023 Automatic Build System <autodist@mambasoft.it> 2021.11.0-1mamba
- automatic version update by autodist

* Tue Jul 25 2023 Automatic Build System <autodist@mambasoft.it> 2021.10.0-1mamba
- automatic version update by autodist

* Wed Apr 12 2023 Automatic Build System <autodist@mambasoft.it> 2021.9.0-1mamba
- automatic version update by autodist

* Mon Apr 03 2023 Automatic Build System <autodist@mambasoft.it> 2021.8.0-1mamba
- automatic version update by autodist

* Thu Sep 22 2022 Automatic Build System <autodist@mambasoft.it> 2021.6.0-1mamba
- automatic version update by autodist

* Fri Jan 07 2022 Automatic Build System <autodist@mambasoft.it> 2021.5.0-1mamba
- automatic version update by autodist

* Wed Sep 09 2020 Silvan Calarco <silvan.calarco@mambasoft.it> 2020.3-1mamba
- update to 2020.3

* Wed Dec 25 2019 Silvan Calarco <silvan.calarco@mambasoft.it> 2020-1mamba
- update to 2020

* Wed Dec 11 2019 Silvan Calarco <silvan.calarco@mambasoft.it> 2019_U9-1mamba
- update to 2019_U9

* Sat Mar 01 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 4.2_20140122-1mamba
- update to 4.2_20140122

* Mon Nov 08 2010 gil <puntogil@libero.it> 2.2-1mamba
- package created by autospec
